==> Enbugger-2.000.tar.gz: Enbugger-2.000/lib/Enbugger/sdb.pm <==
package Enbugger::sdb;

1;

__DATA__
ARGS
BEGIN
CARP_NOT
CommandSet
CreateTTY
CvGV_name
CvGV_name_or_bust
DB
DBGR
DollarCaretP
DollarCaretP_flags
DollarCaretP_flags_r
Dumper
END
FD_TO_CLOSE
IN
ISA
I_m_init
ImmediateStop
LINEINFO
LineInfo
MODIFY_CODE_ATTRIBUTES
NonStop
OUT
OnlyAssertions
ReadLine
RememberOnROptions
RemotePort
SAVEIN
SAVEOUT
Snocheck
Spatt
Srev
TTY
VERSION
XT
__ANON__
_filename
_line
_package
a
action
after
afterinit
alias
arg
args
arrow
asserting_test
assertion
b
b_compile
b_load
b_postpone
balanced_brace_re
bitmask
block
bpoint
break_on_filename_line
break_on_filename_line_range
break_on_line
break_on_load
break_subroutine
breakable_line
breakable_line_in_filename
breakpoint2
callpat
catch
clean_ENV
cmd
cmd_A
cmd_B
cmd_E
cmd_L
cmd_M
cmd_O
cmd_P
cmd_W
cmd_a
cmd_b
cmd_b_line
cmd_b_load
cmd_b_sub
cmd_e
cmd_h
cmd_i
cmd_l
cmd_o
cmd_pre580_D
cmd_pre580_W
cmd_pre580_a
cmd_pre580_b
cmd_pre580_h
cmd_pre580_null
cmd_pre590_prepost
cmd_prepost
cmd_stop
cmd_v
cmd_w
cmd_wrapper
cmdfhs
code
command
cond
config
console
countfile
create_IN_OUT
custom_get_fork_TTY
db_END
db_complete
db_stop
dbdie
dbline
dbwarn
deep
defconf
delete_action
delete_breakpoint
depth
dieLevel
diesignal
dir
doccmd
doret
dpost
dpre
dref
dref2
dump_option
dump_trace
dumpit
emacs
end
end_report
eval
evalarg
evaltext
expand_DollarCaretP_flags
fake::
fall_off_end
file
filename
filename_error
filename_ini
filepat
find_sub
finished
fix_less
fnames
fork_TTY
frame
ftty
fttys
fullname
get_fork_TTY
get_list
gets
had_breakpoints
hasargs
header
help
hints
hist
i
incr
incr_pos
infix
inhibit_exit
ini_INC
ini_assertion
ini_pids
ini_warn
inpat
is_require
is_safe_file
j
kpid
l
lastline
laststep
level
line
lineinfo
linepat
list_modules
lline
lname
lno
lock
max
maxdepth
maxtrace
methods
methods_via
mhash
mode
noTTY
notty
nref
num
od
old_watch
onetimeDump
onetimedumpDepth
option
optionAction
optionRequire
optionVars
option_val
options
options2remember
org
ornaments
os2_get_fork_TTY
osingle
otrace
package
packname
packpat
pager
panic
parse_DollarCaretP_flags
parse_options
pat
pattern
pidprompt
pids
pieces
piped
plinepat
pos
position
post
postponed
postponed_file
postponed_sub
prc
pre
pre580_help
pre580_summary
prefix
pretype
prevbus
prevdie
preview
prevsegv
prevwarn
print
print_help
print_lineinfo
print_trace
psh
rc
rcfile
readline
recallCommand
remoteport
report_break_on_load
rerun
res
reset_IN_OUT
resetterm
restart
rl
rl_attribs
runman
runnonstop
safe_do
save
saved
savout
screen_get_fork_TTY
sdb
second_time
seen
selected
set_list
sethelp
setman
setterm
sh
share
shash
shellBang
show
signal
signalLevel
single
single_get_fork_TTY
skipCvGV
skipfiles
skiplines
skippacks
skipsubs
skipvars
slave_editor
stack
stack_depth
start
stop
string
sub
subname
subpat
subrange
subroutine
subroutine_filename_lines
subs
summary
syntdir
syntfile
system
term
term_pid
tkRunning
tmpconfig
to_watch
trace
truehist
try
tty
typeahead
unbalanced
usercontext
var
var2
varname
vars
wantarray
warn
warnLevel
warnassertions
watchfunction
window
xterm_get_fork_TTY
zcheck
zpat

## Local Variables:
## mode: cperl
## mode: auto-fill
## cperl-indent-level: 4
## End:

==> Enbugger-2.011.tar.gz: Enbugger-2.011/lib/Enbugger/sdb.pm <==
package Enbugger::sdb;

# COPYRIGHT AND LICENCE
#
# Copyright (C) 2007,2008 WhitePages.com, Inc. with primary
# development by Joshua ben Jore.
#
# This program is distributed WITHOUT ANY WARRANTY, including but not
# limited to the implied warranties of merchantability or fitness for
# a particular purpose.
#
# The program is free software.  You may distribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation (either version 2 or any later version)
# and the Perl Artistic License as published by O’Reilly Media, Inc.
# Please open the files named gpl-2.0.txt and Artistic for a copy of
# these licenses.

use strict;
use warnings;

warn __PACKAGE__ . ' is not implemented';

() = -.0

__DATA__
ARGS
BEGIN
CARP_NOT
CommandSet
CreateTTY
CvGV_name
CvGV_name_or_bust
DB
DBGR
DollarCaretP
DollarCaretP_flags
DollarCaretP_flags_r
Dumper
END
FD_TO_CLOSE
IN
ISA
I_m_init
ImmediateStop
LINEINFO
LineInfo
MODIFY_CODE_ATTRIBUTES
NonStop
OUT
OnlyAssertions
ReadLine
RememberOnROptions
RemotePort
SAVEIN
SAVEOUT
Snocheck
Spatt
Srev
TTY
VERSION
XT
__ANON__
_filename
_line
_package
a
action
after
afterinit
alias
arg
args
arrow
asserting_test
assertion
b
b_compile
b_load
b_postpone
balanced_brace_re
bitmask
block
bpoint
break_on_filename_line
break_on_filename_line_range
break_on_line
break_on_load
break_subroutine
breakable_line
breakable_line_in_filename
breakpoint2
callpat
catch
clean_ENV
cmd
cmd_A
cmd_B
cmd_E
cmd_L
cmd_M
cmd_O
cmd_P
cmd_W
cmd_a
cmd_b
cmd_b_line
cmd_b_load
cmd_b_sub
cmd_e
cmd_h
cmd_i
cmd_l
cmd_o
cmd_pre580_D
cmd_pre580_W
cmd_pre580_a
cmd_pre580_b
cmd_pre580_h
cmd_pre580_null
cmd_pre590_prepost
cmd_prepost
cmd_stop
cmd_v
cmd_w
cmd_wrapper
cmdfhs
code
command
cond
config
console
countfile
create_IN_OUT
custom_get_fork_TTY
db_END
db_complete
db_stop
dbdie
dbline
dbwarn
deep
defconf
delete_action
delete_breakpoint
depth
dieLevel
diesignal
dir
doccmd
doret
dpost
dpre
dref
dref2
dump_option
dump_trace
dumpit
emacs
end
end_report
eval
evalarg
evaltext
expand_DollarCaretP_flags
fake::
fall_off_end
file
filename
filename_error
filename_ini
filepat
find_sub
finished
fix_less
fnames
fork_TTY
frame
ftty
fttys
fullname
get_fork_TTY
get_list
gets
had_breakpoints
hasargs
header
help
hints
hist
i
incr
incr_pos
infix
inhibit_exit
ini_INC
ini_assertion
ini_pids
ini_warn
inpat
is_require
is_safe_file
j
kpid
l
lastline
laststep
level
line
lineinfo
linepat
list_modules
lline
lname
lno
lock
max
maxdepth
maxtrace
methods
methods_via
mhash
mode
noTTY
notty
nref
num
od
old_watch
onetimeDump
onetimedumpDepth
option
optionAction
optionRequire
optionVars
option_val
options
options2remember
org
ornaments
os2_get_fork_TTY
osingle
otrace
package
packname
packpat
pager
panic
parse_DollarCaretP_flags
parse_options
pat
pattern
pidprompt
pids
pieces
piped
plinepat
pos
position
post
postponed
postponed_file
postponed_sub
prc
pre
pre580_help
pre580_summary
prefix
pretype
prevbus
prevdie
preview
prevsegv
prevwarn
print
print_help
print_lineinfo
print_trace
psh
rc
rcfile
readline
recallCommand
remoteport
report_break_on_load
rerun
res
reset_IN_OUT
resetterm
restart
rl
rl_attribs
runman
runnonstop
safe_do
save
saved
savout
screen_get_fork_TTY
sdb
second_time
seen
selected
set_list
sethelp
setman
setterm
sh
share
shash
shellBang
show
signal
signalLevel
single
single_get_fork_TTY
skipCvGV
skipfiles
skiplines
skippacks
skipsubs
skipvars
slave_editor
stack
stack_depth
start
stop
string
sub
subname
subpat
subrange
subroutine
subroutine_filename_lines
subs
summary
syntdir
syntfile
system
term
term_pid
tkRunning
tmpconfig
to_watch
trace
truehist
try
tty
typeahead
unbalanced
usercontext
var
var2
varname
vars
wantarray
warn
warnLevel
warnassertions
watchfunction
window
xterm_get_fork_TTY
zcheck
zpat

## Local Variables:
## mode: cperl
## mode: auto-fill
## cperl-indent-level: 4
## End:
